@@ -7,7 +7,7 @@ package conf;  # Don't remove this line!
 #
 # Administrator's email address
 #
-$ADDRESS = 'webmaster@vm42';
+$ADDRESS = 'webmaster@xeon.linet.gr.jp';
 
 
 #===================================================================
@@ -32,11 +32,16 @@ $ALLOW_FILE =	".*\\.(?:$HTML_SUFFIX)|.*\\.txt" . # HTML, plain text
 		"|.*\\.tex|.*\\.dvi" .   	   # TeX, DVI
 		"|.*\\.rpm|.*\\.deb" .   	   # RPM, DEB
 		"|.*\\.doc|.*\\.xls|.*\\.pp[st]" . # Word, Excel, PowerPoint
+                "|.*\\.vs[dst]|.*\\.v[dst]x" .     # Visio
 		"|.*\\.j[sabf]w|.*\\.jtd" .        # Ichitaro 4, 5, 6, 7, 8
 		"|.*\\.sx[widc]" .                 # OpenOffice Writer,Calc,Impress,Draw
+		"|.*\\.od[tspg]" .                 # OpenOffice2.0
 		"|.*\\.rtf" .                      # Rich Text Format
-		"|.*\\.hdml" .			   # HDML
+		"|.*\\.hdml|.*\\.mht" .		   # HDML MHTML
 		"|.*\\.mp3" .			   # MP3 
+		"|.*\\.gnumeric" .                 # Gnumeric
+		"|.*\\.kwd|.*\\.ksp" .             # KWord, KSpread
+		"|.*\\.kpr|.*\\.flw" .             # KPresenter, Kivio
 		"|\\d+|[-\\w]+\\.[1-9n]";          # Mail/News, man
 
 #
@@ -47,6 +52,14 @@ $ALLOW_FILE =	".*\\.(?:$HTML_SUFFIX)|.*\\.txt" . # HTML, plain text
 #
 $DENY_FILE = ".*\\.(gif|png|jpg|jpeg)|.*\\.tar\\.gz|core|.*\\.bak|.*~|\\..*|\x23.*";
 
+#
+# This pattern specifies DDN(DOS Device Name) which will NOT be targeted.
+# NOTE: Only for Windows.
+#       Do NOT use `$' or `^' anchors.
+#       Case-insensitive.
+#
+$DENY_DDN = "con|aux|nul|prn|lpt[1-9]|com[1-9]|clock\$|xmsxxxx0";
+
 #
 # This pattern specifies PATHNAMEs which will NOT be targeted.
 # NOTE: Usually specified by --exclude=regex option.
@@ -99,6 +112,7 @@ $NON_SEPARATION_ELEMENTS = 'A|TT|CODE|SAMP|KBD|VAR|B|STRONG|I|EM|CITE|FONT|U|'.
 #
 $HTML_ATTRIBUTES = 'ALT|SUMMARY|TITLE';
 
+
 #===================================================================
 # 
 # Critical Numbers
@@ -181,25 +195,32 @@ $MAX_FIELD_LENGTH = 200;
 #
 
 #
-# Network Kanji Filter nkf v1.62 or later
+# Network Kanji Filter nkf v1.71 or later
 #
-$NKF = "/usr/local/bin/nkf"; 
+$NKF = "module_nkf"; 
 
 #
-# KAKASI
+# KAKASI 2.x or later
+# Text::Kakasi 1.05 or later
 #
 $KAKASI = "/usr/bin/kakasi -ieuc -oeuc -w";
 
 #
-# ChaSen 1.51 or later (simple wakatigaki)
+# ChaSen 2.02 or later (simple wakatigaki)
+# Text::ChaSen 1.03
 #
 $CHASEN = "no";
 
 #
-# ChaSen 1.51 or later (with noun words extraction)
+# ChaSen 2.02 or later (with noun words extraction)
 #
 $CHASEN_NOUN = "no";
 
+#
+# MeCab
+#
+$MECAB = "no";
+
 #
 # Default Japanese processer: KAKASI or ChaSen.
 #
